@@ -10,25 +10,20 @@ from cca_zoo.models import (
     rCCA,
     CCA,
     PLS,
-    CCA_ALS,
-    SCCA,
-    PMD,
+    SCCA_IPLS,
+    SCCA_PMD,
     ElasticCCA,
     KCCA,
     KTCCA,
     MCCA,
     GCCA,
     TCCA,
-    SpanCCA,
+    SCCA_Span,
     SWCCA,
-    PLS_ALS,
     KGCCA,
     NCCA,
-    ParkhomenkoCCA,
-    SCCA_ADMM,
-    PartialCCA,
+    PartialCCA, PLS_ALS, SCCA_ADMM, SCCA_Parkhomenko,StochasticPowerPLS, IncrementalPLS
 )
-from cca_zoo.utils.plotting import cv_plot
 
 n = 50
 rng = check_random_state(0)
@@ -43,126 +38,75 @@ def test_unregularized_methods():
     # Tests unregularized CCA methods. The idea is that all of these should give the same result.
     latent_dims = 2
     cca = CCA(latent_dims=latent_dims).fit([X, Y])
-    iter = CCA_ALS(
-        latent_dims=latent_dims, tol=1e-9, stochastic=False, random_state=rng
-    ).fit([X, Y])
     gcca = GCCA(latent_dims=latent_dims).fit([X, Y])
     mcca = MCCA(latent_dims=latent_dims, eps=1e-9).fit([X, Y])
     kcca = KCCA(latent_dims=latent_dims).fit([X, Y])
     kgcca = KGCCA(latent_dims=latent_dims).fit([X, Y])
     tcca = TCCA(latent_dims=latent_dims).fit([X, Y])
     corr_cca = cca.score((X, Y))
-    corr_iter = iter.score((X, Y))
     corr_gcca = gcca.score((X, Y))
     corr_mcca = mcca.score((X, Y))
     corr_kcca = kcca.score((X, Y))
     corr_kgcca = kgcca.score((X, Y))
     corr_tcca = tcca.score((X, Y))
-    assert np.testing.assert_array_almost_equal(corr_cca, corr_iter, decimal=1) is None
     assert np.testing.assert_array_almost_equal(corr_cca, corr_mcca, decimal=1) is None
     assert np.testing.assert_array_almost_equal(corr_cca, corr_gcca, decimal=1) is None
     assert np.testing.assert_array_almost_equal(corr_cca, corr_kcca, decimal=1) is None
     assert np.testing.assert_array_almost_equal(corr_cca, corr_tcca, decimal=1) is None
     assert (
-        np.testing.assert_array_almost_equal(corr_kgcca, corr_gcca, decimal=1) is None
+            np.testing.assert_array_almost_equal(corr_kgcca, corr_gcca, decimal=1) is None
     )
     # Check standardized models have standard outputs
     assert (
-        np.testing.assert_allclose(
-            np.linalg.norm(iter.transform((X, Y))[0], axis=0) ** 2, n, rtol=0.2
-        )
-        is None
+            np.testing.assert_allclose(
+                np.linalg.norm(cca.transform((X, Y))[0], axis=0) ** 2, n, rtol=0.2
+            )
+            is None
     )
     assert (
-        np.testing.assert_allclose(
-            np.linalg.norm(cca.transform((X, Y))[0], axis=0) ** 2, n, rtol=0.2
-        )
-        is None
+            np.testing.assert_allclose(
+                np.linalg.norm(mcca.transform((X, Y))[0], axis=0) ** 2, n, rtol=0.2
+            )
+            is None
     )
     assert (
-        np.testing.assert_allclose(
-            np.linalg.norm(mcca.transform((X, Y))[0], axis=0) ** 2, n, rtol=0.2
-        )
-        is None
+            np.testing.assert_allclose(
+                np.linalg.norm(kcca.transform((X, Y))[0], axis=0) ** 2, n, rtol=0.2
+            )
+            is None
     )
     assert (
-        np.testing.assert_allclose(
-            np.linalg.norm(kcca.transform((X, Y))[0], axis=0) ** 2, n, rtol=0.2
-        )
-        is None
+            np.testing.assert_allclose(
+                np.linalg.norm(cca.transform((X, Y))[1], axis=0) ** 2, n, rtol=0.2
+            )
+            is None
     )
     assert (
-        np.testing.assert_allclose(
-            np.linalg.norm(iter.transform((X, Y))[1], axis=0) ** 2, n, rtol=0.2
-        )
-        is None
+            np.testing.assert_allclose(
+                np.linalg.norm(mcca.transform((X, Y))[1], axis=0) ** 2, n, rtol=0.2
+            )
+            is None
     )
     assert (
-        np.testing.assert_allclose(
-            np.linalg.norm(cca.transform((X, Y))[1], axis=0) ** 2, n, rtol=0.2
-        )
-        is None
+            np.testing.assert_allclose(
+                np.linalg.norm(kcca.transform((X, Y))[1], axis=0) ** 2, n, rtol=0.2
+            )
+            is None
     )
-    assert (
-        np.testing.assert_allclose(
-            np.linalg.norm(mcca.transform((X, Y))[1], axis=0) ** 2, n, rtol=0.2
-        )
-        is None
-    )
-    assert (
-        np.testing.assert_allclose(
-            np.linalg.norm(kcca.transform((X, Y))[1], axis=0) ** 2, n, rtol=0.2
-        )
-        is None
-    )
-
-
-def test_sparse_input():
-    # Tests unregularized CCA methods. The idea is that all of these should give the same result.
-    latent_dims = 2
-    cca = CCA(latent_dims=latent_dims, centre=False).fit((X_sp, Y_sp))
-    iter = CCA_ALS(
-        latent_dims=latent_dims,
-        tol=1e-9,
-        stochastic=False,
-        centre=False,
-        random_state=rng,
-    ).fit((X_sp, Y_sp))
-    iter_pls = PLS_ALS(latent_dims=latent_dims, tol=1e-9, centre=False).fit(
-        (X_sp, Y_sp)
-    )
-    gcca = GCCA(latent_dims=latent_dims, centre=False).fit((X_sp, Y_sp))
-    mcca = MCCA(latent_dims=latent_dims, centre=False).fit((X_sp, Y_sp))
-    kcca = KCCA(latent_dims=latent_dims, centre=False).fit((X_sp, Y_sp))
-    scca = SCCA(latent_dims=latent_dims, centre=False, c=0.001).fit((X_sp, Y_sp))
-    corr_cca = cca.score((X, Y))
-    corr_iter = iter.score((X, Y))
-    corr_gcca = gcca.score((X, Y))
-    corr_mcca = mcca.score((X, Y))
-    corr_kcca = kcca.score((X, Y))
-    # Check the correlations from each unregularized method are the same
-    assert np.testing.assert_array_almost_equal(corr_iter, corr_mcca, decimal=1) is None
-    assert np.testing.assert_array_almost_equal(corr_iter, corr_gcca, decimal=1) is None
-    assert np.testing.assert_array_almost_equal(corr_iter, corr_kcca, decimal=1) is None
 
 
 def test_unregularized_multi():
     # Tests unregularized CCA methods for more than 2 views. The idea is that all of these should give the same result.
     latent_dims = 2
     cca = rCCA(latent_dims=latent_dims).fit((X, Y, Z))
-    iter = CCA_ALS(
-        latent_dims=latent_dims, stochastic=False, tol=1e-12, random_state=rng
-    ).fit((X, Y, Z))
     gcca = GCCA(latent_dims=latent_dims).fit((X, Y, Z))
     mcca = MCCA(latent_dims=latent_dims).fit((X, Y, Z))
     kcca = KCCA(latent_dims=latent_dims).fit((X, Y, Z))
     corr_cca = cca.score((X, Y, Z))
-    corr_iter = iter.score((X, Y, Z))
     corr_gcca = gcca.score((X, Y, Z))
     corr_mcca = mcca.score((X, Y, Z))
     corr_kcca = kcca.score((X, Y, Z))
     # Check the correlations from each unregularized method are the same
-    assert np.testing.assert_array_almost_equal(corr_cca, corr_iter, decimal=1) is None
     assert np.testing.assert_array_almost_equal(corr_cca, corr_mcca, decimal=1) is None
     assert np.testing.assert_array_almost_equal(corr_cca, corr_gcca, decimal=1) is None
     assert np.testing.assert_array_almost_equal(corr_cca, corr_kcca, decimal=1) is None
@@ -187,60 +131,31 @@ def test_regularized_methods():
     # Check the correlations from each unregularized method are the same
     assert np.testing.assert_array_almost_equal(corr_pls, corr_mcca, decimal=1) is None
     assert (
-        np.testing.assert_array_almost_equal(corr_pls, corr_kernel, decimal=1) is None
+            np.testing.assert_array_almost_equal(corr_pls, corr_kernel, decimal=1) is None
     )
     assert np.testing.assert_array_almost_equal(corr_pls, corr_rcca, decimal=1) is None
 
 
-def test_non_negative_methods():
-    latent_dims = 2
-    nnscca = SCCA(
-        latent_dims=latent_dims,
-        tol=1e-9,
-        positive=True,
-        c=[1e-6, 1e-6],
-        random_state=rng,
-        initialization="random",
-    ).fit((X, Y))
-    nnelastic = ElasticCCA(
-        latent_dims=latent_dims,
-        tol=1e-9,
-        positive=True,
-        l1_ratio=[0.5, 0.5],
-        c=[1e-5, 1e-5],
-        random_state=rng,
-        initialization="random",
-    ).fit((X, Y))
-    nnals = CCA_ALS(
-        latent_dims=latent_dims,
-        tol=1e-9,
-        positive=True,
-        random_state=rng,
-        initialization="pls",
-    ).fit((X, Y))
-    assert np.testing.assert_array_less(-1e-9, nnelastic.weights[0]) is None
-    assert np.testing.assert_array_less(-1e-9, nnelastic.weights[1]) is None
-    assert np.testing.assert_array_less(-1e-9, nnals.weights[0]) is None
-    assert np.testing.assert_array_less(-1e-9, nnals.weights[1]) is None
-    assert np.testing.assert_array_less(-1e-9, nnscca.weights[0]) is None
-    assert np.testing.assert_array_less(-1e-9, nnscca.weights[1]) is None
-
-
 def test_sparse_methods():
+    c1 = [1e-1]
+    c2 = [1e-1]
+    param_grid = {"c": [c1, c2]}
+    scca_cv = GridSearchCV(SCCA_IPLS(random_state=rng), param_grid=param_grid).fit([X, Y])
     c1 = [0.1, 0.2]
     c2 = [0.1, 0.2]
     param_grid = {"c": [c1, c2]}
-    pmd_cv = GridSearchCV(PMD(random_state=rng), param_grid=param_grid).fit([X, Y])
-    cv_plot(pmd_cv.cv_results_)
-    c1 = [5e-1]
-    c2 = [1e-1]
-    param_grid = {"c": [c1, c2]}
-    scca_cv = GridSearchCV(SCCA(random_state=rng), param_grid=param_grid).fit([X, Y])
+    pmd_cv = GridSearchCV(SCCA_PMD(random_state=rng), param_grid=param_grid).fit([X, Y])
+    c1 = loguniform(1e-1, 2e-1)
+    c2 = loguniform(1e-1, 2e-1)
+    param_grid = {"c": [c1, c2], "l1_ratio": [[0.9], [0.9]]}
+    elastic_cv = RandomizedSearchCV(
+        ElasticCCA(random_state=rng), param_distributions=param_grid, n_iter=4
+    ).fit([X, Y])
     c1 = [1e-1]
     c2 = [1e-1]
     param_grid = {"c": [c1, c2]}
     parkhomenko_cv = GridSearchCV(
-        ParkhomenkoCCA(random_state=rng), param_grid=param_grid
+        SCCA_Parkhomenko(random_state=rng), param_grid=param_grid
     ).fit([X, Y])
     c1 = [2e-2]
     c2 = [1e-2]
@@ -248,12 +163,6 @@ def test_sparse_methods():
     admm_cv = GridSearchCV(SCCA_ADMM(random_state=rng), param_grid=param_grid).fit(
         [X, Y]
     )
-    c1 = loguniform(1e-1, 2e-1)
-    c2 = loguniform(1e-1, 2e-1)
-    param_grid = {"c": [c1, c2], "l1_ratio": [[0.9], [0.9]]}
-    elastic_cv = RandomizedSearchCV(
-        ElasticCCA(random_state=rng), param_distributions=param_grid, n_iter=4
-    ).fit([X, Y])
     assert (pmd_cv.best_estimator_.weights[0] == 0).sum() > 0
     assert (pmd_cv.best_estimator_.weights[1] == 0).sum() > 0
     assert (scca_cv.best_estimator_.weights[0] == 0).sum() > 0
@@ -265,6 +174,12 @@ def test_sparse_methods():
     assert (elastic_cv.best_estimator_.weights[0] == 0).sum() > 0
     assert (elastic_cv.best_estimator_.weights[1] == 0).sum() > 0
 
+def test_pls():
+    pls_als = PLS_ALS(latent_dims=3)
+    pls = PLS(latent_dims=3)
+    pls_als.fit((X, Y))
+    pls.fit((X, Y))
+    assert np.allclose(np.abs(pls_als.weights[0]), np.abs(pls.weights[0]), rtol=1e-3)
 
 def test_weighted_GCCA_methods():
     # TODO we have view weighted GCCA and missing observation GCCA
@@ -281,10 +196,10 @@ def test_weighted_GCCA_methods():
     K[0, 200:] = 0
     unobserved_gcca = GCCA(latent_dims=latent_dims, c=[c, c]).fit((X, Y), K=K)
     assert (
-        np.testing.assert_array_almost_equal(
-            corr_unweighted_gcca, corr_deweighted_gcca, decimal=1
-        )
-        is None
+            np.testing.assert_array_almost_equal(
+                corr_unweighted_gcca, corr_deweighted_gcca, decimal=1
+            )
+            is None
     )
 
 
@@ -306,7 +221,7 @@ def test_NCCA():
 
 
 def test_l0():
-    span_cca = SpanCCA(
+    span_cca = SCCA_Span(
         latent_dims=1, regularisation="l0", c=[2, 2], random_state=rng
     ).fit([X, Y])
     swcca = SWCCA(latent_dims=1, c=[2, 2], sample_support=5, random_state=rng).fit(
@@ -331,12 +246,17 @@ def test_partialcca():
     )
 
 
-def test_pls():
-    pls_als = PLS_ALS(latent_dims=3)
-    pls = PLS(latent_dims=3)
-    pls_als.fit((X, Y))
-    pls.fit((X, Y))
-    assert np.allclose(np.abs(pls_als.weights[0]), np.abs(pls.weights[0]), rtol=1e-3)
+def test_stochastic():
+    pls = PLS(latent_dims=1).fit((X, Y))
+    ipls = IncrementalPLS(
+        latent_dims=1, epochs=10, simple=False, batch_size=1
+    ).fit((X, Y))
+    spls = StochasticPowerPLS(latent_dims=1, epochs=10, batch_size=1,lr=1e-1).fit((X, Y))
+    pls_score = pls.score((X, Y))
+    ipls_score = ipls.score((X, Y))
+    spls_score = spls.score((X, Y))
+    assert np.testing.assert_array_almost_equal(pls_score, ipls_score, decimal=1) is None
+    assert np.testing.assert_array_almost_equal(pls_score, spls_score, decimal=1) is None
 
 
 def test_PCCA():
@@ -354,11 +274,11 @@ def test_PCCA():
     ).fit([X, Y])
     # Test that vanilla CCA and VCCA produce roughly similar latent space ie they are correlated
     assert (
-        np.abs(
-            np.corrcoef(
-                cca.transform([X, Y])[1].T,
-                pcca.posterior_samples["z"].mean(axis=0)[:, 0],
-            )[0, 1]
-        )
-        > 0.9
+            np.abs(
+                np.corrcoef(
+                    cca.transform([X, Y])[1].T,
+                    pcca.posterior_samples["z"].mean(axis=0)[:, 0],
+                )[0, 1]
+            )
+            > 0.9
     )
